# coding: utf-8

"""
    Robust Intelligence Firewall REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Auth-Token` header. Your AI Firewall Agent domain forms the base of the URL for REST API calls. To find the Agent domain in the Robust Intelligence UI, click AI Firewall: Settings icon: Firewall Settings. Find your agent in the Firewall Agent Status: Agents Setup page, and copy its URL from the table.

    The version of the OpenAPI document: 1.0
    Contact: dev@robustintelligence.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ri.fwclient.models.id import ID
from ri.fwclient.models.processed_request import ProcessedRequest
from ri.fwclient.models.rule_details import RuleDetails
from ri.fwclient.models.validation_type import ValidationType
from typing import Optional, Set
from typing_extensions import Self

class ValidateResponse(BaseModel):
    """
    ValidateResponse is the response to a single validation request. Note: this does not follow the same RI API standards, because we want this to be easily consumed by security team's event frameworks.
    """ # noqa: E501
    allowed_input_rules: Optional[List[StrictStr]] = Field(default=None, description="Complete list of all rules that allowed the input.", alias="allowedInputRules")
    allowed_output_rules: Optional[List[StrictStr]] = Field(default=None, description="Complete list of all rules that allowed the output.", alias="allowedOutputRules")
    firewall_instance_id: Optional[ID] = Field(default=None, alias="firewallInstanceId")
    flagged_input_rules: Optional[List[StrictStr]] = Field(default=None, description="Complete list of all rules that flagged the input.", alias="flaggedInputRules")
    flagged_output_rules: Optional[List[StrictStr]] = Field(default=None, description="Complete list of all rules that flagged the output.", alias="flaggedOutputRules")
    flagged_scan_types: Optional[List[ValidationType]] = Field(default=None, description="Lists what was flagged- the input, the output, or both. This is always a subset of scan_types.", alias="flaggedScanTypes")
    input_results: Optional[Dict[str, RuleDetails]] = Field(default=None, description="Succinct results of the Firewall for model input. The key is a rule name.", alias="inputResults")
    output_results: Optional[Dict[str, RuleDetails]] = Field(default=None, description="Succinct results of the Firewall for model output. The key is a rule name.", alias="outputResults")
    product: Optional[StrictStr] = Field(default=None, description="The name of the product that is processing this request.")
    request: Optional[ProcessedRequest] = None
    scan_types: Optional[List[ValidationType]] = Field(default=None, description="Lists what was scanned- the input, the output, or both.", alias="scanTypes")
    scanned_time: Optional[datetime] = Field(default=None, description="Date and time at which the Firewall allowed or denied this request.", alias="scannedTime")
    schema_version: Optional[StrictStr] = Field(default=None, description="API schema version is the version of the API response. This should be updated whenever we make semantic changes to the response.", alias="schemaVersion")
    trace_id: Optional[ID] = Field(default=None, alias="traceId")
    vendor_name: Optional[StrictStr] = Field(default=None, description="The name of the entity that manages the Firewall Instance.", alias="vendorName")
    version: Optional[StrictStr] = Field(default=None, description="Firewall semantic version.")
    __properties: ClassVar[List[str]] = ["allowedInputRules", "allowedOutputRules", "firewallInstanceId", "flaggedInputRules", "flaggedOutputRules", "flaggedScanTypes", "inputResults", "outputResults", "product", "request", "scanTypes", "scannedTime", "schemaVersion", "traceId", "vendorName", "version"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ValidateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of firewall_instance_id
        if self.firewall_instance_id:
            _dict['firewallInstanceId'] = self.firewall_instance_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in input_results (dict)
        _field_dict = {}
        if self.input_results:
            for _key in self.input_results:
                if self.input_results[_key]:
                    _field_dict[_key] = self.input_results[_key].to_dict()
            _dict['inputResults'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in output_results (dict)
        _field_dict = {}
        if self.output_results:
            for _key in self.output_results:
                if self.output_results[_key]:
                    _field_dict[_key] = self.output_results[_key].to_dict()
            _dict['outputResults'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of request
        if self.request:
            _dict['request'] = self.request.to_dict()
        # override the default output from pydantic by calling `to_dict()` of trace_id
        if self.trace_id:
            _dict['traceId'] = self.trace_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ValidateResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowedInputRules": obj.get("allowedInputRules"),
            "allowedOutputRules": obj.get("allowedOutputRules"),
            "firewallInstanceId": ID.from_dict(obj["firewallInstanceId"]) if obj.get("firewallInstanceId") is not None else None,
            "flaggedInputRules": obj.get("flaggedInputRules"),
            "flaggedOutputRules": obj.get("flaggedOutputRules"),
            "flaggedScanTypes": obj.get("flaggedScanTypes"),
            "inputResults": dict(
                (_k, RuleDetails.from_dict(_v))
                for _k, _v in obj["inputResults"].items()
            )
            if obj.get("inputResults") is not None
            else None,
            "outputResults": dict(
                (_k, RuleDetails.from_dict(_v))
                for _k, _v in obj["outputResults"].items()
            )
            if obj.get("outputResults") is not None
            else None,
            "product": obj.get("product"),
            "request": ProcessedRequest.from_dict(obj["request"]) if obj.get("request") is not None else None,
            "scanTypes": obj.get("scanTypes"),
            "scannedTime": obj.get("scannedTime"),
            "schemaVersion": obj.get("schemaVersion"),
            "traceId": ID.from_dict(obj["traceId"]) if obj.get("traceId") is not None else None,
            "vendorName": obj.get("vendorName"),
            "version": obj.get("version")
        })
        return _obj


